@@ -21,12 +21,6 @@ class QRCodeSerializer(serializers.ModelSerializer):
     # image_url = serializers.SerializerMethodField(method_name='get_image_url', read_only=True)
     # download_url = serializers.SerializerMethodField(method_name='get_dl_url', read_only=True)
 
-    def create(self, validated_data):
-        validated_dept = validated_data.pop('department')
-        dept, created = Department.objects.get_or_create(name=validated_dept['name'])
-        code = QRCode.objects.create(**validated_data, department=dept)
-        return code
-
     # def get_image_url(self, obj):
     #     path = reverse('code-detail', kwargs={'short_uuid': obj.short_uuid})
     #     url = self.context['request'].build_absolute_uri(path)
